from sphire.tests.test_protocol_janni import *
from sphire.tests.test_protocol_cryolo import *
DataSet(name='negative_stain',
        folder='negative_stain',
        files={
            'allMics': '*.tif',
            'mic1': '8b001.tif',
            'mic2': '20180612_SOS1_dil2_SS2_009.tif',
        })
